<?php // Plugin Core

if (!defined('ABSPATH')) exit;

function disable_gutenberg_init($is_enabled, $post_type) {
	
	if (disable_gutenberg($is_enabled, $post_type)) {
		
		disable_gutenberg_remove();
		
		return false;
		
	}
	
	return $is_enabled;
	
}

function disable_gutenberg($is_enabled, $post_type) {
	
	if (!$is_enabled) return false;
	
	if (isset($_GET['classic-editor'])) return true;
	
	$options = disable_gutenberg_get_options();
	
	$disable_all = (isset($options['disable-all']) && !empty($options['disable-all'])) ? true : false;
	
	if ($disable_all) return true;
	
	foreach (disable_gutenberg_get_enabled_post_types() as $type) {
		
		if ($post_type === $type) return true;
		
	}
	
	foreach (disable_gutenberg_get_enabled_user_roles() as $role) {
		
		$roles = disable_gutenberg_get_current_user_roles();
		
		if (is_array($roles) && in_array($role, $roles)) return true;
		
	}
	
	if (disable_gutenberg_disable_templates() || disable_gutenberg_disable_ids()) return true;
	
	return false;
	
}

function disable_gutenberg_get_current_user_roles($user = null) {
	
	if (is_user_logged_in()) {
		
		$user = $user ? new WP_User($user) : wp_get_current_user();
		
		return $user->roles ? (array) $user->roles : false;
		
	}
	
	return false;
	
}

function disable_gutenberg_get_user_roles() {
	
	$roles = get_editable_roles();
	
	$types = array();
	
	foreach ($roles as $key => $value) {
		
		$label = isset($value['name']) ? $value['name'] : null;
		
		$types[$key]['name']  = $key;
		$types[$key]['label'] = $label;
		
	}
	
	return apply_filters('disable_gutenberg_get_user_roles', $types);
	
}

function disable_gutenberg_get_enabled_user_roles() {
	
	$options = disable_gutenberg_get_options();
	
	$array = array();
	
	foreach ($options as $key => $value) {
		
		preg_match('/^user-role_(.*)$/i', $key, $matches);
		
		if ($value && isset($matches[1]) && !empty($matches[1])) $array[] = $matches[1];
		
	}
	
	return apply_filters('disable_gutenberg_get_enabled_user_roles', $array);
	
}

function disable_gutenberg_get_post_types() {
	
	$post_types = get_post_types(array(), 'objects');
	
	$unset = array('attachment', 'revision', 'nav_menu_item', 'custom_css', 'customize_changeset', 'oembed_cache');
	
	$unset = apply_filters('disable_gutenberg_post_types_unset', $unset);
	
	$types = array();
	
	foreach($post_types as $key => $post_type) {
		
		$types[$key]['name']  = $post_type->name;
		$types[$key]['label'] = $post_type->label;
		
		if (in_array($post_type->name, $unset) || !post_type_supports($post_type->name, 'custom-fields')) unset($types[$key]);
		
	}
	
	return apply_filters('disable_gutenberg_get_post_types', $types);
	
}

function disable_gutenberg_get_enabled_post_types() {
	
	$options = disable_gutenberg_get_options();
	
	$array = array();
	
	foreach ($options as $key => $value) {
		
		preg_match('/^post-type_(.*)$/i', $key, $matches);
		
		if ($value && isset($matches[1]) && !empty($matches[1])) $array[] = $matches[1];
		
	}
	
	return apply_filters('disable_gutenberg_get_enabled_post_types', $array);
	
}

function disable_gutenberg_disable_templates() {
	
	$excluded = array();
	
	$template = '';
	
	$disable = false;
	
	$post_id = isset($_GET['post']) ? intval($_GET['post']) : null;
	
	if (is_admin() && !empty($post_id)) {
		
		$options = disable_gutenberg_get_options();
		
		$excluded = isset($options['templates']) ? $options['templates'] : null;
		
		$excluded = array_map('trim', explode(',', $excluded));
		
		$template = get_page_template_slug($post_id);
		
	}
	
	if (!empty($excluded) && !empty($template)) {
		
		$disable = in_array($template, $excluded, true);
		
	}
	
	return $disable;
	
}

function disable_gutenberg_disable_ids() {
	
	$excluded = array();
	
	$post_id = isset($_GET['post']) ? intval($_GET['post']) : null;
	
	if (is_admin() && !empty($post_id)) {
		
		$options = disable_gutenberg_get_options();
		
		$excluded = isset($options['post-ids']) ? $options['post-ids'] : null;
		
		$excluded = array_map('trim', explode(',', $excluded));
		
	}
	
	return in_array($post_id, $excluded);
	
}

function disable_gutenberg_disable_nag() {
	
	$options = disable_gutenberg_get_options();
	
	$disable_nag = (isset($options['disable-nag']) && !empty($options['disable-nag'])) ? true : false;
	
	if ($disable_nag) remove_filter('try_gutenberg_panel', 'wp_try_gutenberg_panel'); // until WP 5.0 beta
	
}

function disable_gutenberg_menu_items() {
	
	$options = disable_gutenberg_get_options();
	
	$hide_plugin    = (isset($options['hide-menu']) && !empty($options['hide-menu'])) ? true : false;
	$hide_gutenberg = (isset($options['hide-gut'])  && !empty($options['hide-gut']))  ? true : false;
	
	if ($hide_plugin)    remove_submenu_page('options-general.php', 'disable-gutenberg');
	if ($hide_gutenberg) remove_menu_page('gutenberg');
	
}

function disable_gutenberg_is_gutenberg_active() {
	
	$gutenberg = has_filter('replace_editor', 'gutenberg_init') ? true : false;
	
	$block_editor = version_compare($GLOBALS['wp_version'], '5.0-beta', '>') ? true : false;
	
	if ($gutenberg || $block_editor) return true;
	
	return false;
	
}

function disable_gutenberg_post_or_page() {
	
	global $pagenow;
	
	$type = null;
	
	if ($pagenow === 'edit.php') {
		
		if (!isset($_GET['post_type'])) {
			
			$type = 'post'; // posts @ edit.php
			
		} elseif (isset($_GET['post_type']) && $_GET['post_type'] === 'page') {
			
			$type = 'page'; // pages @ edit.php?post_type=page
			
		}
		
	} elseif ($pagenow === 'post.php' && isset($_GET['post'])) {
		
		$post_type = get_post_type($_GET['post']);
		
		if ($post_type === 'post') {
			
			$type = 'post'; // post.php?post=1&action=edit
			  
		} elseif ($post_type === 'page') {
			
			$type = 'page'; // post.php?post=1&action=edit
			  
		}
		
	} elseif ($pagenow === 'post-new.php') {
		
		if (!isset($_GET['post_type'])) {
			
			$type = 'post'; // post-new.php
			
		} elseif (isset($_GET['post_type']) && $_GET['post_type'] === 'page') {
			
			$type = 'page'; // post-new.php?post_type=page
			
		}
		
	} 
	
	return $type;
	
}



// THANKS to Classic Editor for next several functions
// NOTE: these functions are disabled until further notice

function disable_gutenberg_add_submenus() {
	
	$post_type = disable_gutenberg_post_or_page();
	
	$is_active = disable_gutenberg_is_gutenberg_active();
	
	$disable = ($post_type) ? disable_gutenberg($is_active, $post_type) : false;
	
	if ($disable && version_compare(get_bloginfo('version'), '5.0-beta', '>')) return;
	
	foreach (get_post_types(array('show_ui' => true)) as $type) {
		
		$type_obj = get_post_type_object($type);
		
		if (!$type_obj->show_in_menu || !post_type_supports($type, 'editor')) continue;
		
		if ($type_obj->show_in_menu === true) {
			
			if ('post' === $type) {
				
				$parent_slug = 'edit.php';
				
			} elseif ('page' === $type) {
				
				$parent_slug = 'edit.php?post_type=page';
				
			} else {
				
				continue;
				
			}
			
		} else {
			
			$parent_slug = $type_obj->show_in_menu;
			
		}
		
		$item_name = $type_obj->labels->add_new .' '. __('(Classic)', 'disable-gutenberg');
		
		add_submenu_page($parent_slug, $type_obj->labels->add_new, $item_name, $type_obj->cap->edit_posts, 'post-new.php?post_type='. $type .'&classic-editor');
		
	}
	
}

function disable_gutenberg_page_row_actions($actions, $post) {
	
	$is_active = disable_gutenberg_is_gutenberg_active();
	
	if (disable_gutenberg($is_active, $post->post_type)) return $actions;
	
	if (!$is_active || array_key_exists('classic', $actions)) return $actions;
	
	if ('trash' === $post->post_status || !post_type_supports($post->post_type, 'editor')) return $actions;
	
	$edit_url = get_edit_post_link($post->ID, 'raw');
	
	if (!$edit_url) return $actions;

	$edit_url = add_query_arg('classic-editor', '', $edit_url);
	
	$title = _draft_or_post_title($post->ID);
	
	$edit_action = array(
		
		'classic' => sprintf(
			
			'<a href="%s" aria-label="%s">%s</a>',
			
			esc_url($edit_url),
			
			esc_attr(sprintf(
				
				__('Edit &#8220;%s&#8221; with Classic Editor', 'disable-gutenberg'),
				
				$title
				
			)),
			
			__('Edit (Classic)', 'disable-gutenberg')
			
		),
		
	);
	
	$edit_offset = array_search('edit', array_keys($actions), true);
	
	array_splice($actions, $edit_offset + 1, 0, $edit_action);
	
	return $actions;
	
}

function disable_gutenberg_get_edit_post_link($url) {
	
	global $current_screen;
	
	if (!isset($_REQUEST['classic-editor']) && !disable_gutenberg(disable_gutenberg_is_gutenberg_active(), $current_screen->post_type)) return $url;
	
	$url = add_query_arg('classic-editor', '', $url);
	
	return $url;
	
}

function disable_gutenberg_redirect_post_location($location) {
	
	global $current_screen;
	
	if (!isset($_REQUEST['classic-editor']) && !disable_gutenberg(disable_gutenberg_is_gutenberg_active(), $current_screen->post_type)) return $location;
	
	if (isset($_REQUEST['classic-editor']) || (isset($_POST['_wp_http_referer']) && strpos($_POST['_wp_http_referer'], '&classic-editor') !== false)) {
		
		$location = add_query_arg('classic-editor', '', $location);
		
	}
	
	return $location;
	
}

function disable_gutenberg_edit_form_top() {
	
	global $current_screen;
	
	if (!isset($_GET['classic-editor']) && !disable_gutenberg(disable_gutenberg_is_gutenberg_active(), $current_screen->post_type)) return;
	
	?>
	
	<input type="hidden" name="classic-editor" value="" />
	
	<?php
	
}
